.. pyqode documentation master file, created by
   sphinx-quickstart on Sun Oct 12 18:28:02 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyqode.core's API reference documentation!
=====================================================

**pyqode.core** is the core framework of the `pyQode`_ project. It contains the
base classes and a set of extensions (modes/panels/managers) that you can use
to create a specialised code editor. It also provides a basic generic code
editor that you can use as a fallback when there is no specialised editor for
a given language.

- `Issue tracker`_
- `Wiki`_
- `API reference`_
- `Contributing`_
- `Changelog`_
- `Screenshots`_


.. _Changelog: https://github.com/pyQode/pyqode.core/blob/master/CHANGELOG.rst
.. _Contributing: https://github.com/pyQode/pyqode.core/blob/master/CONTRIBUTING.rst
.. _pyQode: https://github.com/pyQode/pyQode
.. _Screenshots: https://github.com/pyQode/pyQode/wiki/Screenshots-and-videos#pyqodecore-screenshots
.. _Issue tracker: https://github.com/pyQode/pyQode/issues
.. _Wiki: https://github.com/pyQode/pyQode/wiki
.. _API reference: https://pythonhosted.org/pyqode.core/
.. _Readme: https://github.com/pyQode/pyqode.core/blob/master/README.rst

This documentation contains the **API reference documentation** and the
**official examples**.

.. note:: We recommend you to start with the `Readme`_ and the `Wiki`_ before
          reading this document*.


API reference:
==============

.. toctree::
   :maxdepth: 3

   pyqode.core

Examples:
=========

.. toctree::
   :maxdepth: 3

   examples

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

